.g-ldap-server-list-title{color:#555;border-bottom:1px solid #eee;margin:10px 0;font-size:16px}.g-ldap-server-form{margin-bottom:12px}.g-ldap-server-form .g-ldap-test-result{margin-top:10px}.g-ldap-server-form .g-ldap-test-result[status=success]{color:#0a0}.g-ldap-server-form .g-ldap-test-result[status=failure]{color:#a00}
/*$vite$:1*/